@@ -90,13 +90,12 @@ class LabHandler(JupyterHandler):
             if not name.endswith('_url'):
                 continue
             full_name = _camelCase('full_' + name)
-            full_url = ujoin(base_url, getattr(config, name))
+            full_url = getattr(config, name)
+            if not is_url(full_url):
+                # Relative URL will be prefixed with base_url
+                full_url = ujoin(base_url, full_url)
             page_config[full_name] = full_url
 
-        # JSON escape Python values in page_config
-        for key, value in page_config.items():
-            page_config[key] = json.dumps(str(value))[1:-1]
-
         # Load the current page config file if available.
         page_config_file = os.path.join(settings_dir, 'page_config.json')
         if os.path.exists(page_config_file):
